import * as FridaJs from 'frida-js';
import { HtkConfig } from '../../config';
/**
 * Terminology:
 * - FridaHost: a device which may contain 1+ Frida targets
 * - FridaTarget: a single app that can be intercepted
 **/
export interface FridaHost {
    id: string;
    name: string;
    type: string;
    state: 'unavailable' | 'setup-required' | 'launch-required' | 'available';
    targets?: FridaTarget[];
}
export interface FridaTarget {
    id: string;
    name: string;
}
export declare const FRIDA_VERSION = "16.6.1";
export declare const FRIDA_DEFAULT_PORT = 27042;
export declare const FRIDA_ALTERNATE_PORT = 24072;
export declare const FRIDA_BINARY_NAME: string;
export declare const FRIDA_SRIS: {
    readonly android: {
        readonly arm: "sha512-bLIDVOMwACFYC/tPkM2lsx7mdwLALnY1ScTqqAy+wkBD1kYPVx4LAF77hbIh49kotRyGll4FV2N0t3dD03I+OA==";
        readonly arm64: "sha512-kPcOEHSceFdts1nnUz/Vjmf2igyayEgCHc+slapr6GjCX0nC83eO8Psq8IF1UnDFx32jrVVvjRzJzTe6P5a85g==";
        readonly x86: "sha512-89IwpL5ki5nOU/sdjnQ7fItseUq1SpYr0HMMFKJMZzpfPQMNXFow5ps4l1ZpK/hdUFCVPHvxynhBc1ZTvcVDlQ==";
        readonly x86_64: "sha512-KBBj09sceLT6Sar4aTxZ1dJaoalBJZ4DfnoTRPER5KVwIAplTwbUVJtsnSI1gSWPyELq9XjO6ZjsWKOaQC79gg==";
    };
};
export declare const getFridaServer: (config: HtkConfig, platform: 'android', arch: 'arm' | 'arm64' | 'x86' | 'x86_64') => Promise<import("stream").PassThrough | import("fs").ReadStream>;
export declare const cleanupOldFridaServers: (config: HtkConfig) => Promise<void>;
export declare function killProcess(session: FridaJs.FridaAgentSession): Promise<void>;
export declare function testAndSelectProxyAddress(session: FridaJs.FridaAgentSession, proxyPort: number, options?: {
    extraAddresses?: string[];
}): Promise<string>;
/**
 * Launch a script, watching for errors during its initial exception, and logging any
 * output or returned messages from the session to the console.
 *
 * Note that only one session monitor can be active at any time, so this will replace
 * any existing session message monitoring.
 */
export declare function launchScript(targetName: string, session: FridaJs.FridaAgentSession, script: string): Promise<void>;
